@@ -14,25 +14,26 @@
 
 # pylint: disable=unused-import,no-name-in-module
 
+import importlib.util
 import inspect
 import locale
 import sys
 
 from platformio.exception import UserSideException
 
-if sys.version_info >= (3,):
-    if sys.version_info >= (3, 7):
-        from asyncio import create_task as aio_create_task
-        from asyncio import get_running_loop as aio_get_running_loop
-    else:
-        from asyncio import ensure_future as aio_create_task
-        from asyncio import get_event_loop as aio_get_running_loop
+if sys.version_info >= (3, 7):
+    from asyncio import create_task as aio_create_task
+    from asyncio import get_running_loop as aio_get_running_loop
+else:
+    from asyncio import ensure_future as aio_create_task
+    from asyncio import get_event_loop as aio_get_running_loop
 
 
-PY2 = sys.version_info[0] == 2
+PY2 = sys.version_info[0] == 2  # DO NOT REMOVE IT. ESP8266/ESP32 depend on it
 IS_CYGWIN = sys.platform.startswith("cygwin")
 IS_WINDOWS = WINDOWS = sys.platform.startswith("win")
 IS_MACOS = sys.platform.startswith("darwin")
+MISSING = object()
 string_types = (str,)
 
 
@@ -57,8 +58,6 @@ def hashlib_encode_data(data):
 
 
 def load_python_module(name, pathname):
-    import importlib.util  # pylint: disable=import-outside-toplevel
-
     spec = importlib.util.spec_from_file_location(name, pathname)
     module = importlib.util.module_from_spec(spec)
     spec.loader.exec_module(module)
