@@ -33,5 +33,5 @@ $INIT_BREAK
 """
 
     def __init__(self, *args, **kwargs):
-        super(QemuDebugConfig, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.port = ":1234"
