@@ -21,8 +21,8 @@ import tarfile
 from urllib.parse import urlparse
 
 from platformio import util
-from platformio.clients.http import fetch_remote_content
 from platformio.compat import get_object_members, string_types
+from platformio.http import fetch_remote_content
 from platformio.package.exception import ManifestParserError, UnknownManifestError
 from platformio.project.helpers import is_platformio_project
 
