@@ -22,14 +22,23 @@ import tempfile
 from platformio import fs
 from platformio.compat import IS_WINDOWS
 from platformio.package.exception import PackageException, UserSideException
-from platformio.package.manifest.parser import ManifestFileType, ManifestParserFactory
+from platformio.package.manifest.parser import (
+    LibraryPropertiesManifestParser,
+    ManifestFileType,
+    ManifestParserFactory,
+)
 from platformio.package.manifest.schema import ManifestSchema
 from platformio.package.meta import PackageItem
 from platformio.package.unpack import FileUnpacker
 
 
 class PackagePacker(object):
-    INCLUDE_DEFAULT = ManifestFileType.items().values()
+    INCLUDE_DEFAULT = list(ManifestFileType.items().values()) + [
+        "README",
+        "README.md",
+        "README.rst",
+        "LICENSE",
+    ]
     EXCLUDE_DEFAULT = [
         # PlatformIO internal files
         PackageItem.METAFILE_NAME,
@@ -42,6 +51,8 @@ class PackagePacker(object):
         ".vscode",
         ".cache",
         "**/.cache",
+        "**/__pycache__",
+        "**/*.pyc",
         # VCS
         ".git/",
         ".hg/",
@@ -49,16 +60,26 @@ class PackagePacker(object):
     ]
     EXCLUDE_EXTRA = [
         # Tests
-        "tests?",
+        "test",
+        "tests",
         # Docs
         "doc",
         "docs",
         "mkdocs",
+        "doxygen",
+        "*.doxyfile",
+        "html",
+        "media",
         "**/*.[pP][dD][fF]",
-        "**/*.[dD][oO][cC]?",
-        "**/*.[pP][pP][tT]?",
+        "**/*.[dD][oO][cC]",
+        "**/*.[dD][oO][cC][xX]",
+        "**/*.[pP][pP][tT]",
+        "**/*.[pP][pP][tT][xX]",
+        "**/*.[xX][lL][sS]",
+        "**/*.[xX][lL][sS][xX]",
         "**/*.[dD][oO][xX]",
-        "**/*.[hH][tT][mM]?",
+        "**/*.[hH][tT][mM]",
+        "**/*.[hH][tT][mM][lL]",
         "**/*.[tT][eE][xX]",
         "**/*.[jJ][sS]",
         "**/*.[cC][sS][sS]",
@@ -67,6 +88,7 @@ class PackagePacker(object):
         "**/*.[jJ][pP][eE][gG]",
         "**/*.[pP][nN][gG]",
         "**/*.[gG][iI][fF]",
+        "**/*.[sS][vV][gG]",
         "**/*.[zZ][iI][pP]",
         "**/*.[gG][zZ]",
         "**/*.3[gG][pP]",
@@ -74,14 +96,13 @@ class PackagePacker(object):
         "**/*.[mM][pP][34]",
         "**/*.[pP][sS][dD]",
         "**/*.[wW][aA][wW]",
+        "**/*.sqlite",
     ]
     EXCLUDE_LIBRARY_EXTRA = [
         "assets",
         "extra",
+        "extras",
         "resources",
-        "html",
-        "media",
-        "doxygen",
         "**/build/",
         "**/*.flat",
         "**/*.[jJ][aA][rR]",
@@ -96,6 +117,7 @@ class PackagePacker(object):
     def __init__(self, package, manifest_uri=None):
         self.package = package
         self.manifest_uri = manifest_uri
+        self.manifest_parser = None
 
     @staticmethod
     def get_archive_name(name, version, system=None):
@@ -109,6 +131,20 @@ class PackagePacker(object):
             ),
         )
 
+    @staticmethod
+    def load_gitignore_filters(path):
+        result = []
+        with open(path, encoding="utf8") as fp:
+            for line in fp.readlines():
+                line = line.strip()
+                if not line or line.startswith(("#")):
+                    continue
+                if line.startswith("!"):
+                    result.append(f"+<{line[1:]}>")
+                else:
+                    result.append(f"-<{line}>")
+        return result
+
     def pack(self, dst=None):
         tmp_dir = tempfile.mkdtemp()
         try:
@@ -127,7 +163,8 @@ class PackagePacker(object):
                 src = tmp_dir
 
             src = self.find_source_root(src)
-            manifest = self.load_manifest(src)
+            self.manifest_parser = ManifestParserFactory.new_from_dir(src)
+            manifest = ManifestSchema().load_manifest(self.manifest_parser.as_dict())
             filename = self.get_archive_name(
                 manifest["name"],
                 manifest["version"],
@@ -139,15 +176,10 @@ class PackagePacker(object):
             elif os.path.isdir(dst):
                 dst = os.path.join(dst, filename)
 
-            return self._create_tarball(src, dst, manifest)
+            return self.create_tarball(src, dst, manifest)
         finally:
             shutil.rmtree(tmp_dir)
 
-    @staticmethod
-    def load_manifest(src):
-        mp = ManifestParserFactory.new_from_dir(src)
-        return ManifestSchema().load_manifest(mp.as_dict())
-
     def find_source_root(self, src):
         if self.manifest_uri:
             mp = (
@@ -171,7 +203,7 @@ class PackagePacker(object):
 
         return src
 
-    def _create_tarball(self, src, dst, manifest):
+    def create_tarball(self, src, dst, manifest):
         include = manifest.get("export", {}).get("include")
         exclude = manifest.get("export", {}).get("exclude")
         # remap root
@@ -212,9 +244,15 @@ class PackagePacker(object):
         result += ["-<%s>" % p for p in self.EXCLUDE_DEFAULT]
         # exclude items declared in manifest
         result += ["-<%s>" % p for p in exclude or []]
+
         # apply extra excludes if no custom "export" field in manifest
-        if not include and not exclude:
+        if (not include and not exclude) or isinstance(
+            self.manifest_parser, LibraryPropertiesManifestParser
+        ):
             result += ["-<%s>" % p for p in exclude_extra]
-        # automatically include manifests
+            if os.path.exists(os.path.join(src, ".gitignore")):
+                result += self.load_gitignore_filters(os.path.join(src, ".gitignore"))
+
+        # always include manifests and relevant files
         result += ["+<%s>" % p for p in self.INCLUDE_DEFAULT]
         return result
