@@ -28,7 +28,7 @@ from traceback import format_exc
 import requests
 
 from platformio import __version__, app, exception, util
-from platformio.commands import PlatformioCLI
+from platformio.cli import PlatformioCLI
 from platformio.compat import hashlib_encode_data, string_types
 from platformio.proc import is_ci, is_container
 from platformio.project.helpers import is_platformio_project
